<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>UDMX</name>
    <message>
        <location filename="udmx.cpp" line="100"/>
        <source>This plugin provides DMX output support for Anyma uDMX devices.</source>
        <translation type="unfinished">このプラグインは、uDMX(μDMX)デバイスにDMX信号を送信します。</translation>
    </message>
    <message>
        <location filename="udmx.cpp" line="199"/>
        <source>Do you wish to re-scan your hardware?</source>
        <translation type="unfinished">ハードウェアを再スキャンしますか？</translation>
    </message>
</context>
<context>
    <name>UDMXDevice</name>
    <message>
        <location filename="udmxdevice.cpp" line="122"/>
        <source>Unknown</source>
        <translation type="unfinished">Unknown</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="142"/>
        <source>Device name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="144"/>
        <source>DMX Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="146"/>
        <source>DMX Frame Frequency</source>
        <translation type="unfinished">DMX Frame Frequency</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="149"/>
        <source>Bad</source>
        <translation type="unfinished">Bad</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="151"/>
        <source>Good</source>
        <translation type="unfinished">Good</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="153"/>
        <source>Patch this device to a universe to find out.</source>
        <translation type="unfinished">Patch this device to a universe to find out.</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="154"/>
        <source>System Timer Accuracy</source>
        <translation type="unfinished">System Timer Accuracy</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="159"/>
        <source>Device not in use</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
